<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Selecione um ou mais dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkAudioController_wl</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Selecione um ou mais dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkCameraSingle</name>
    <message>
        <source>Remove window frame</source>
        <translation>Remover moldura da janela</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Girar na vertical</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Girar na horizontal</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Inverter</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Cinzento</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Preto e branco</translation>
    </message>
    <message>
        <source>Switch to Window</source>
        <translation>Mudar para Janela</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Alternar para Tela Cheia</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Camera</source>
        <translation>Câmera</translation>
    </message>
</context>
<context>
    <name>QvkCiscoFinishDialog</name>
    <message>
        <source>The setup was successful.</source>
        <translation>Instalação concluída com sucesso.</translation>
    </message>
    <message>
        <source>Close this window and start vokoscreenNG again.</source>
        <translation>Feche esta Janela e Inicie o vokoscreenNG novamente.</translation>
    </message>
    <message>
        <source>Have fun with vokoscreenNG</source>
        <translation>Divirta-se com o vokoscreenNG!</translation>
    </message>
</context>
<context>
    <name>QvkDirDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Nenhum gerenciador de arquivos encontrado.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Por favor instale um gerenciador de arquivos.</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs_wl</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Nenhum gerenciador de arquivos encontrado.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Por favor instale um gerenciador de arquivos.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>A gravação não foi iniciada, não há espaço suficiente no disco.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>O limite de espaço livre em disco foi atingido.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Limite de espaço livre no disco</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>A gravação foi interrompida, não há espaço livre em disco.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>No filemanager found.</source>
        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
        <translation>Nenhum gerenciador de arquivos encontrado.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Por favor instale um gerenciador de arquivos.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Código-Fonte</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Homepage</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traduções</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Doações</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow_wl</name>
    <message>
        <source>Sourcecode</source>
        <translation>Código-Fonte</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Homepage</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traduções</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Doações</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Nenhum gerenciador de arquivos encontrado.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Por favor instale um gerenciador de arquivos.</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Selecione um ou mais dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher_wl</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Selecione um ou mais dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise_wl</name>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
</context>
<context>
    <name>QvkSnapshot</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Nenhum gerenciador de arquivos encontrado.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Por favor instale um gerenciador de arquivos.</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Câmera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Zoom</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Câmera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Zoom</translation>
    </message>
</context>
<context>
    <name>QvkWASAPIController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Selecione um ou mais dispositivos</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Girar na horizontal</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Girar na vertical</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Inverter</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Cinzento</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Preto e branco</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Remover moldura da janela</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Configurações da câmera</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Zoom</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Contagem Regressiva</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Tamanho do vídeo:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Espaço disponível no disco:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informação</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Tempo de gravação:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Áudio</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Quadros</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Codec de vídeo </translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Codec de áudio</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Não gravar o cursor do mouse</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Hora</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minuto</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Iniciar o cronômetro</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Para gravação após</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Horas</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minutos</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Segundos</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Diretório do vídeo</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Limite de espaço livre no disco</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Mostrar na área de notificação</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Espera em segundos antes de começar gravando</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Buscar atualizações</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Disponível</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Não disponível</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproduzir</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Pasta</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Câmera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Inverter</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Cinzento</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Reproduzir a última gravação</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Abrir pasta</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimizar ao iniciar a gravação</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Iniciar minimizado</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Girar na horizontal</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Girar na vertical</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Preto e branco</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Remover moldura da janela</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Redefinir todas as configurações na próxima inicialização</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Direitos autorais e licença das imagens</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Captura de Tela</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Reprodutor</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Log</translation>
    </message>
    <message>
        <source>Automatically</source>
        <translation>Automaticamente</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>Criar imagens das abas</translation>
    </message>
    <message>
        <source>License information</source>
        <translation>Infomações de Licença</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>LIGADO</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>DESLIGADO</translation>
    </message>
    <message>
        <source>Global keyboard shortcuts</source>
        <translation>Atalhos de teclado globais</translation>
    </message>
    <message>
        <source>Assigned shortcut keys.</source>
        <translation>Atalhos de teclado atribuídos</translation>
    </message>
    <message>
        <source>Keyboard shortcut not assigned or assigned more than once.</source>
        <translation>Atalho de teclado não atribuído ou atribuído em duplicidade.</translation>
    </message>
    <message>
        <source>If it shows assigned but does not work, it is being used by another program.</source>
        <translation>Se o atalho foi atribuído, mas não funciona, ele pode estar sendo utilizado por outro programa.</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation>Captura instantânea</translation>
    </message>
    <message>
        <source>Imagepath</source>
        <translation>Diretório da imagem</translation>
    </message>
    <message>
        <source>Hide this window</source>
        <translation>Ocultar esta janela</translation>
    </message>
    <message>
        <source>Seconds wait before recording</source>
        <translation>Aguarde segundos antes de gravar</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Janela</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Tela cheia</translation>
    </message>
</context>
<context>
    <name>formMainWindow_wl</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Direitos autorais e licença das imagens</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>Criar imagens das abas</translation>
    </message>
    <message>
        <source>License information</source>
        <translation>Infomações de Licença</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>LIGADO</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>DESLIGADO</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Tempo de gravação:</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Tamanho do vídeo:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Espaço disponível no disco:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informação</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Janela</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Tela cheia</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Codec de vídeo </translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Quadros</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Disponível</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Não disponível</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Pasta</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Não gravar o cursor do mouse</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Codec de áudio</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Diretório do vídeo</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Contagem Regressiva</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Inverter</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Cinzento</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Preto e branco</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Câmera</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Girar na vertical</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Girar na horizontal</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Remover moldura da janela</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Espera em segundos antes de começar gravando</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Hide this window</source>
        <translation>Ocultar esta janela</translation>
    </message>
    <message>
        <source>Seconds wait before recording</source>
        <translation>Aguarde segundos antes de gravar</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Direitos autorais e licença das imagens</translation>
    </message>
</context>
<context>
    <name>playerGST</name>
    <message>
        <source>Play</source>
        <translation>Reproduzir</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
</context>
</TS>